@@ -382,3 +382,11 @@ gis_page_shown (GisPage *page)
   if (GIS_PAGE_GET_CLASS (page)->shown)
     GIS_PAGE_GET_CLASS (page)->shown (page);
 }
+
+gboolean
+gis_page_skip (GisPage *page)
+{
+  if (GIS_PAGE_GET_CLASS (page)->skip)
+    return GIS_PAGE_GET_CLASS (page)->skip (page);
+  return TRUE;
+}
