@@ -50,7 +50,8 @@ GType gis_account_page_local_get_type (void);
 
 gboolean gis_account_page_local_validate (GisAccountPageLocal *local);
 gboolean gis_account_page_local_apply (GisAccountPageLocal *local, GisPage *page);
-void gis_account_page_local_create_user (GisAccountPageLocal *local);
+void gis_account_page_local_create_user (GisAccountPageLocal *local,
+                                         GisPage             *page);
 void gis_account_page_local_shown (GisAccountPageLocal *local);
 
 G_END_DECLS
